Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(847)

Unified Diff: third_party/WebKit/Source/platform/heap/HeapPage.cpp

Issue 1411843008: Make blink platform time consistent with the timer virtual time (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix CachingCorrectnessTest Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/heap/HeapPage.cpp
diff --git a/third_party/WebKit/Source/platform/heap/HeapPage.cpp b/third_party/WebKit/Source/platform/heap/HeapPage.cpp
index 4ee87f0fea6c2adb3cd7e0bde17424874351f4d6..10b30f8de75112e2dafff32746ad59ed959836b9 100644
--- a/third_party/WebKit/Source/platform/heap/HeapPage.cpp
+++ b/third_party/WebKit/Source/platform/heap/HeapPage.cpp
@@ -329,7 +329,7 @@ void BaseHeap::sweepUnsweptPage()
bool BaseHeap::lazySweepWithDeadline(double deadlineSeconds)
{
// It might be heavy to call Platform::current()->monotonicallyIncreasingTime()
// per page (i.e., 128 KB sweep or one LargeObject sweep), so we check
// the deadline per 10 pages.
static const int deadlineCheckInterval = 10;
@@ -342,7 +342,7 @@ bool BaseHeap::lazySweepWithDeadline(double deadlineSeconds)
while (m_firstUnsweptPage) {
sweepUnsweptPage();
if (pageCount % deadlineCheckInterval == 0) {
- if (deadlineSeconds <= Platform::current()->monotonicallyIncreasingTime()) {
+ if (deadlineSeconds <= Platform::current()->monotonicallyIncreasingTimeSeconds()) {
// Deadline has come.
Heap::reportMemoryUsageForTracing();
return !m_firstUnsweptPage;
@@ -329,7 +329,7 @@ void BaseHeap::sweepUnsweptPage()
bool BaseHeap::lazySweepWithDeadline(double deadlineSeconds)
{
- // It might be heavy to call Platform::current()->monotonicallyIncreasingTime()
+ // It might be heavy to call Platform::current()->monotonicallyIncreasingTimeSeconds()
// per page (i.e., 128 KB sweep or one LargeObject sweep), so we check
// the deadline per 10 pages.

Powered by Google App Engine
This is Rietveld 408576698